==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/FinalValueLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { FinalValueLayerDescription } from "./FinalValueLayerDescription";
/**
 * @hidden
 */
var FinalValueLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinalValueLayerDescriptionMetadata, _super);
    function FinalValueLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinalValueLayerDescriptionMetadata.b = function (a) {
        if (FinalValueLayerDescriptionMetadata.a == null) {
            FinalValueLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinalValueLayerDescriptionMetadata.c(FinalValueLayerDescriptionMetadata.a);
        }
        if (a.k(FinalValueLayerDescriptionMetadata.a)) {
            return;
        }
        a.ab(FinalValueLayerDescriptionMetadata.a);
    };
    FinalValueLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetSeriesName", "String");
        a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
        a.item("FinalValueSelectionMode", "ExportedType:string:FinalValueSelectionMode");
        a.item("FinalValueSelectionMode@names", "Auto;FinalVisible;FinalVisibleInterpolated;Final");
        a.item("AxisAnnotationTextColor", "Brush");
        a.item("AxisAnnotationBackground", "Brush");
        a.item("AxisAnnotationBackgroundCornerRadius", "Number:double");
        a.item("AxisAnnotationInterpolatedValuePrecision", "Number:int");
        a.item("AxisAnnotationOutline", "Brush");
        a.item("AxisAnnotationPaddingLeft", "Number:double");
        a.item("AxisAnnotationPaddingTop", "Number:double");
        a.item("AxisAnnotationPaddingRight", "Number:double");
        a.item("AxisAnnotationPaddingBottom", "Number:double");
        a.item("AxisAnnotationStrokeThickness", "Number:double");
    };
    FinalValueLayerDescriptionMetadata.d = function (a) {
        FinalValueLayerDescriptionMetadata.b(a);
        a.ad("FinalValueLayer", function () { return new FinalValueLayerDescription(); });
        a.ac("FinalValueLayer", FinalValueLayerDescriptionMetadata.a);
    };
    FinalValueLayerDescriptionMetadata.$t = markType(FinalValueLayerDescriptionMetadata, 'FinalValueLayerDescriptionMetadata');
    FinalValueLayerDescriptionMetadata.a = null;
    return FinalValueLayerDescriptionMetadata;
}(Base));
export { FinalValueLayerDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/FinalValueLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { FinalValueLayerDescription } from "./FinalValueLayerDescription";
/**
 * @hidden
 */
var FinalValueLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinalValueLayerDescriptionMetadata, _super);
    function FinalValueLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinalValueLayerDescriptionMetadata.b = function (a) {
        if (FinalValueLayerDescriptionMetadata.a == null) {
            FinalValueLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinalValueLayerDescriptionMetadata.c(FinalValueLayerDescriptionMetadata.a);
        }
        if (a.k(FinalValueLayerDescriptionMetadata.a)) {
            return;
        }
        a.ac(FinalValueLayerDescriptionMetadata.a);
    };
    FinalValueLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetSeriesName", "String");
        a.item("TargetSeriesRef", "(w:TargetSeries,wf:TargetSeries)DataRef::object");
        a.item("FinalValueSelectionMode", "ExportedType:string:FinalValueSelectionMode");
        a.item("FinalValueSelectionMode@names", "Auto;FinalVisible;FinalVisibleInterpolated;Final");
        a.item("AxisAnnotationTextColor", "Brush");
        a.item("AxisAnnotationBackground", "Brush");
        a.item("AxisAnnotationBackgroundCornerRadius", "Number:double");
        a.item("AxisAnnotationInterpolatedValuePrecision", "Number:int");
        a.item("AxisAnnotationOutline", "Brush");
        a.item("AxisAnnotationPaddingLeft", "Number:double");
        a.item("AxisAnnotationPaddingTop", "Number:double");
        a.item("AxisAnnotationPaddingRight", "Number:double");
        a.item("AxisAnnotationPaddingBottom", "Number:double");
        a.item("AxisAnnotationStrokeThickness", "Number:double");
        a.item("AxisAnnotationFormatLabelRef", "EventRef::axisAnnotationFormatLabel");
    };
    FinalValueLayerDescriptionMetadata.d = function (a) {
        FinalValueLayerDescriptionMetadata.b(a);
        a.ae("FinalValueLayer", function () { return new FinalValueLayerDescription(); });
        a.ad("FinalValueLayer", FinalValueLayerDescriptionMetadata.a);
    };
    FinalValueLayerDescriptionMetadata.$t = markType(FinalValueLayerDescriptionMetadata, 'FinalValueLayerDescriptionMetadata');
    FinalValueLayerDescriptionMetadata.a = null;
    return FinalValueLayerDescriptionMetadata;
}(Base));
export { FinalValueLayerDescriptionMetadata };
